# Copyright The Lightning AI team.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from typing import Dict

from lightning_cloud.openapi import ApiClient, AuthServiceApi, V1LoginRequest

from lightning_app.utilities.login import Auth


# This class joins common things for reading logs,
# initialization and getting API token
class _AuthTokenGetter:
    def __init__(self, api_client: ApiClient):
        self.api_client = api_client
        self._auth = Auth()
        self._auth.authenticate()
        self._auth_service = AuthServiceApi(api_client)

    def _get_api_token(self) -> str:
        token_resp = self._auth_service.auth_service_login(
            body=V1LoginRequest(
                username=self._auth.username,
                api_key=self._auth.api_key,
            )
        )
        return token_resp.token


def _credential_string_to_basic_auth_params(credential_string: str) -> Dict[str, str]:
    """Returns the name/ID pair for each given Secret name.

    Raises a `ValueError` if any of the given Secret names do not exist.
    """
    if credential_string.count(":") != 1:
        raise ValueError(
            "Credential string must follow the format username:password; "
            + f"the provided one ('{credential_string}') does not."
        )

    username, password = credential_string.split(":")

    if not username:
        raise ValueError("Username cannot be empty.")

    if not password:
        raise ValueError("Password cannot be empty.")

    return {"username": username, "password": password}
